# OAuth Berechtigungen für sendende Systeme

Für den Zugriff auf die API des Zustelldienstes werden vom Autorisierungsserver Berechtigungen in Form von OAuth-Scopes
vergeben. Sendende Systeme werden damit berechtigt Einreichungen vorzunehmen. Empfangende Systeme werden damit
berechtigt Einreichungen abzuholen.

## Zustellberechtigungs-Scopes

Die Zustellberechtigungs-Scopes erlauben dem Zustelldienst festzustellen, ob ein sendendes System eine Einreichung an
einen bestimmten Zustellpunkt übermitteln darf. Zustellberechtigungs-Scopes werden im Self-Service-Portal bei der
Registrierung von API-Clients festgelegt und sind
im [`scope`-Claim des Access Tokens](/details/infrastructure-docs/sender.md) hinterlegt.

### Zusammensetzung der Zustellberechtigungs-Scopes

Der Zustellberechtigungs-Scope kann eine beliebige Anzahl an Regionen oder eine Kombination aus Region und Leistungstyp
enthalten:

#### Scope: Region

- **Typ**: Geographische Zuordnung
- **Beispiel**: `send:region:DE081150045045`
- **Erläuterung**: Eine geographische Zuordnung zu einem Bundesland, Landkreis, einer Gemeinde etc. erfolgt über den [Amtlichen Regionalschlüssel](https://de.wikipedia.org/wiki/Amtlicher_Gemeindeschl%C3%BCssel#Regionalschl%C3%BCssel), vorangestellt mit `DE`. Siehe auch: [Gemeindeverzeichnis des Statistischen Bundesamtes](https://www.destatis.de/DE/Themen/Laender-Regionen/Regionales/Gemeindeverzeichnis/_inhalt.html)

#### Scope: Leistung (innerhalb LeiKa)

- **Typ**: Leistungstyp innerhalb des LeiKa (LeiKa-ID)
- **Beispiel**: `send:service:urn:de:fim:leika:leistung:99108008252000`
- **Erläuterung**: Eine Leistung, die im [Leistungskatalog der öffentlichen Verwaltung](https://leitfaden.ozg-umsetzung.de/display/OZG/2.1+Verwaltungsleistungen+im+Sinne+des+OZG) (LeiKa) verzeichnet ist, wird über ihre LeiKa-ID, vorangestellt mit `urn:de:fim:leika:leistung:` referenziert. Der LeiKa ist im [FIM-Portal](https://fimportal.de/kataloge#download-leistungen) abrufbar.

#### Scope: Leistung (außerhalb LeiKa)

- **Typ**: Leistungstyp außerhalb des LeiKa
- **Beispiel**: `send:service:urn:myleistung`
- **Erläuterung**: Eine Leistung, die nicht im Leistungskatalog abgebildet ist, kann übergangsweise über eine andere Leistungs-ID referenziert werden. Diese ID muss eindeutig sein.

#### Scope: Kombination Region/Leistung

- **Typ**: Kombination aus Leistungstyp und Region
- **Beispiel**: `send:region:DE081100000000+send:service:urn:de:fim:leika:leistung:99108008252000` oder `send:region:DE081100000000+send:service:urn:myleistung`
- **Erläuterung**: Eine Kombination aus amtlichem Gemeindeschlüssel und LeiKa-ID. Hier erfolgt eine Einschränkung nach beiden angegeben Kriterien (Zugriff nur auf spezifische Leistung in der angegebenen Region).

### Einschränkung: Region

Eine Einschränkung der Berechtigung für bestimmte Regionen erfolgt auf Basis des
zwölfstelligen [Amtlichen Regionalschlüssels (ARS)](https://de.wikipedia.org/wiki/Amtlicher_Gemeindeschl%C3%BCssel#Regionalschl%C3%BCssel),
vorangestellt mit `DE`. Eine Liste der amtlichen Regionalschlüssel findet sich
im [Gemeindeverzeichnis des Statistischen Bundesamtes](https://www.destatis.de/DE/Themen/Laender-Regionen/Regionales/Gemeindeverzeichnis/_inhalt.html)
sowie im [XRepository](https://www.xrepository.de/details/urn:de:bund:destatis:bevoelkerungsstatistik:schluessel:rs).

**Hinweis**: Ohne zusätzliche Einschränkung auf einen Leistungstyp ist ein Zustellberechtigungs-Scope für alle
Leistungstypen in der angegebenen Region gültig.

**Beispiel**: Mit der Angabe des zwölfstelligen ARS kann die Stadt Sindelfingen eindeutig adressiert werden:

```
send:region:DE081150045045
```

Werden nicht alle zwölf Stellen des ARS angegeben, sondern nur ein Prefix des ARS, so können statt einer spezifischen
Gemeinde auch darüberliegende Kreise, Regierungsbezirke oder Bundesländer abgebildet werden. Wird ein solcher Prefix
eines ARS angegeben, schließt dieser alle sich darin befindlichen Gliederungen mit ein.

**Beispiel**: Dieser Schlüssel steht für alle Leistungen in der Region Stuttgart und schließt alle darunterliegenden
Landkreise, Städte und Gemeinden mit ein:

```
send:region:DE0811
```

**Beispiel**: Der folgenden Schlüssel referenziert über die Angabe der ersten beiden Ziffern des ARS alle
Regierungsbezirke, Landkreise, Städte und Gemeinden im Bundesland Brandenburg:

```
send:region:DE12
```

**Beispiel**: Über die ausschließliche Angabe des Prefix `DE` können alle Gebietskörperschaften in Deutschland
referenziert werden:

```
send:region:DE
```

Eine Einschränkung auf konkrete Verwaltungsebenen ist durch das Auffüllen des ARS auf zwölf Stellen mit Nullen möglich.

**Beispiel**: Der folgende Schlüssel referenziert explizit nur den Kreis Böblingen, nicht jedoch beispielsweise die
Stadt Leonberg, die im Kreis Böblingen liegt. Hierdurch ist eine Einschränkung auf Zustellpunkte möglich, die von der
Kreisverwaltung Böblingen betrieben werden, ohne eine Berechtigung für Zustellpunkte der Stadt Leonberg zu gewähren.

```
send:region:DE081150000000
```

### Einschränkung: Leistungstypen

Um sendende Systeme zur Einreichung bei allen Zustellpunkten eines bestimmten Leistungstyps zu berechtigen, ist eine
Vergabe von Berechtigungen auf Basis von Leistungs-IDs möglich. Ein Download des Leistungskatalogs mit allen
LeiKa-Schlüsseln ist [über das FIM-Portal](https://fimportal.de/kataloge#download-leistungen) möglich.

**Beispiel**: Berechtigung für die LeiKa-Leistung
"[Begutachung von abgeschleppten Fahrzeugen](https://fimportal.de/detail/L/99108008252000)":

```
send:service:urn:de:fim:leika:leistung:99108008252000
```

**Hinweis**: Eine Einschränkung auf bestimmte Leistungstypen erfolgt im Autorisierungsserver **immer** kombiniert mit
einer geographische Zuordnung. Um ein sendendes System zur Einreichung bei allen existierenden Zustellpunkten eines
Leistungstyps zu berechtigen wird der Schlüssel `send:region:DE` genutzt (siehe nächster Abschnitt). Hier wäre das:

```
send:region:DE+send:service:urn:de:fim:leika:leistung:99108008252000
```

### Einschrankung: Region+Leistungstyp

Über die Kombination einer geographischen Zuordnung mit einem Leistungstyp über das Plus-Symbol (`+`) ist eine
Einschränkung auf Verwaltungsleistungen in einer bestimmten Region möglich. Hierbei wird immer zuerst ("vor dem `+`")
eine Einschränkung nach der Region und dann ("nach dem `+`") eine Einschränkung nach dem Leistungstyp vorgenommen.

**Beispiel**: Der folgende Zustellberechtigungs-Scope berechtigt zur Einreichung für die LeiKa-Leistung
"[Begutachung von abgeschleppten Fahrzeugen](https://fimportal.de/detail/L/99108008252000)" im Landkreis Böblingen:

```
send:region:DE08115+send:service:urn:de:fim:leika:leistung:99108008252000
```

### Erteilung mehrerer Zustellberechtigungen

Der `scope` Claim des Access Tokens kann mehrere Zustellberechtigungs-Scopes – separiert mit Leerzeichen
gemäß [RFC 6749, Abschnitt 3.3](https://datatracker.ietf.org/doc/html/rfc6749#section-3.3) – enthalten. Diese sind
unabhängig voneinander zu betrachten. Ein sendendes System ist zur Einreichung bei allen Zustellpunkten berechtigt, auf
die mindestens einer der Zustellberechtigungs-Scopes zutrifft.

**Beispiel**: Mit diesem Zustellberechtigungs-Scope kann ein sendendes System Einreichungen für alle Leistungen im
Landkreis Böblingen, als auch die
Leistung "[Begutachung von abgeschleppten Fahrzeugen](https://fimportal.de/detail/L/99108008252000)"
im Bundesland Brandenburg vornehmen:

```
send:region:DE08115 send:region:DE12+send:service:urn:de:fim:leika:leistung::99108008252000
```
